translate.misc.optrecurse.ManHelpFormatter

Package translate :: Package misc :: Module optrecurse :: Class ManHelpFormatter |
[hide private]
[frames] | no frames]

# Class ManHelpFormatter

source code

Instance Methods | [hide private]
__init__(self, indent_increment=0, max_help_position=0, width=80, short_first=1) | source code
format_option_strings(self, option) Return a comma-separated list of option strings & metavariables. | source code
Inherited from `optparse.HelpFormatter`: `dedent`, `expand_default`, `format_description`, `format_epilog`, `format_heading`, `format_option`, `format_usage`, `indent`, `set_long_opt_delimiter`, `set_parser`, `set_short_opt_delimiter`, `store_option_strings` Inherited from `optparse.HelpFormatter` (private): `_format_text`

Class Variables | [hide private]
Inherited from `optparse.HelpFormatter`: `NO_DEFAULT_VALUE`

Method Details | [hide private]

### __init__(self, indent_increment=0, max_help_position=0, width=80, short_first=1) (Constructor) | source code
Overrides: optparse.HelpFormatter.__init__

### format_option_strings(self, option) | source code
Return a comma-separated list of option strings & metavariables. Overrides: optparse.HelpFormatter.format_option_strings